@@ -1,4 +1,3 @@
-import os
 import sys
 import time
 from pyspecs._reporting import ConsoleReporter
@@ -7,7 +6,7 @@ from pyspecs._should import _Should
 from pyspecs._step import Step, _StepCounter
 
 
-__version__ = '2.1'
+__version__ = '2.2'
 
 
 _reporter = ConsoleReporter()
@@ -45,4 +44,17 @@ def catch(callable_):
     else:
         return None
     finally:
-        sys.exc_clear()
\ No newline at end of file
+        sys.exc_clear()
+
+
+def finish():
+    """
+    Call this method from your test script after all scenarios like so:
+
+    if __name__ == '__main__':
+        pyspecs.finish()
+
+    This allows you to invoke your test file as a main module, limiting
+    the scenarios executed to those in the file in question.
+    """
+    _reporter.aggregate()
\ No newline at end of file
